slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVGetType

Gets the BV type name (as a string) from the BV context.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVGetType(BV bv,BVType *type)

Not Collective

### Input Parameter

| bv | - the basis vectors context

### Output Parameter

| type | - name of the type of basis vectors

### See Also

BVSetType()

### Level

intermediate

### Location

src/sys/classes/bv/interface/bvbasic.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages